@@ -23,7 +23,7 @@
 #ifndef __BOOT_APPEND_H
 #define __BOOT_APPEND_H
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 
 #include "boot-settings.h"
 
@@ -39,8 +39,8 @@ typedef struct
 	   GtkRadioButton *append_vga_manual;
 	   GtkRadioButton *append_vga_ask;
 
-	   GtkOptionMenu *append_menu_colors;
-	   GtkOptionMenu *append_menu_res;
+	   GtkComboBox   *append_menu_colors;
+	   GtkComboBox   *append_menu_res;
 	   
 	   GtkLabel      *append_label_colors;
 	   GtkLabel      *append_label_res;
