@@ -51,6 +51,7 @@ struct _GstConnectionDialog {
 
   /* wireless */
   GtkWidget *essid;
+  GtkWidget *key_type_combo;
   GtkWidget *wep_key;
 
   /* plip */
@@ -73,6 +74,7 @@ struct _GstConnectionDialog {
   GtkWidget *volume;
   GtkWidget *dial_type;
   GtkWidget *default_gw;
+  GtkWidget *peerdns;
   GtkWidget *persist;
 
   /* frames */
