@@ -22,8 +22,8 @@
 #  include <config.h>
 #endif
 
-#include <gnome.h>
 #include <glade/glade.h>
+#include <glib/gi18n.h>
 
 #include "gst.h"
 #include "gst-network-tool.h"
@@ -38,6 +38,7 @@ static GstDialogSignal signals[] = {
   { "properties_button",            "clicked", G_CALLBACK (on_iface_properties_clicked) },
   { "activate_button",              "clicked", G_CALLBACK (on_activate_button_clicked) },
   { "deactivate_button",            "clicked", G_CALLBACK (on_deactivate_button_clicked) },
+  { "gateways_combo",               "changed", G_CALLBACK (on_gateway_combo_changed) },
   /* general tab */
   { "hostname",                     "changed", G_CALLBACK (gst_dialog_modify_cb) },
   { "domain",                       "changed", G_CALLBACK (gst_dialog_modify_cb) },
@@ -48,6 +49,7 @@ static GstDialogSignal signals[] = {
   /* host aliases dialog */
   { "host_alias_address",           "changed", G_CALLBACK (on_host_aliases_dialog_changed) },
   /* connection dialog */
+  { "connection_config_dialog",     "delete-event", G_CALLBACK (on_connection_dialog_close) },
   { "connection_device_active",     "clicked", G_CALLBACK (on_iface_active_changed) },
   { "connection_ppp_device_active", "clicked", G_CALLBACK (on_iface_active_changed) },
   { "connection_bootproto",         "changed", G_CALLBACK (on_bootproto_changed) },
@@ -59,6 +61,7 @@ static GstDialogSignal signals[] = {
   { "connection_ppp_device_active", "toggled", G_CALLBACK (on_dialog_changed) },
   { "connection_device_active",     "toggled", G_CALLBACK (on_dialog_changed) },
   { "connection_essid",             "changed", G_CALLBACK (on_dialog_changed) },
+  { "connection_wep_key_type",      "changed", G_CALLBACK (on_dialog_changed) },
   { "connection_wep_key",           "changed", G_CALLBACK (on_dialog_changed) },
   { "connection_bootproto",         "changed", G_CALLBACK (on_dialog_changed) },
   { "connection_address",           "changed", G_CALLBACK (on_dialog_changed) },
